@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -1008,7 +1008,7 @@ function checkMenuState(moduleObject, element, event)
 	}
 	
 	// Check defaultmenu
-	if(srcElement.className.indexOf("arrow") < 0) {
+	if(srcElement.className && srcElement.className.indexOf("arrow") < 0) {
 		var defaultmenu = dhtml.getElementById("defaultmenu");
 
 		if(defaultmenu) {
@@ -1017,7 +1017,7 @@ function checkMenuState(moduleObject, element, event)
 	}
 	
 	// Check ComboBox's
-	if(srcElement.className.indexOf("arrow") < 0) {
+	if(srcElement.className && srcElement.className.indexOf("arrow") < 0) {
 		var comboBoxes = dhtml.comboBoxes;
 		
 		for(var i in comboBoxes)
