@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -678,10 +678,14 @@ function callbackdeleteoccurence()
 // If 'send' is TRUE, then send a cancellation
 function deleteAppointment()
 {
-	var basedate = dhtml.getElementById("basedate").getAttribute("unixtime");
-	basedate = basedate ? parseInt(basedate, 10) : 0;
+	if(module.messageentryid) {
+		var basedate = dhtml.getElementById("basedate").getAttribute("unixtime");
+		basedate = basedate ? parseInt(basedate, 10) : 0;
 
-	module.deleteMessage(basedate);
+		module.deleteMessage(basedate);
+	} else {
+		window.close();
+	}
 }
 
 function onChangeReminder()
@@ -1174,7 +1178,46 @@ function categoriesCallBack(categories) {
 }
 
 function abCallBackRecipients(recips) {
-	dhtml.getElementById("to").value = recips['to'].value;
+	var attendees = recips['to'];
+
+	// if user has selected resource then automatically mark it as resource instead of required attendee
+	if(attendees.multiple){
+		for(var key in attendees){
+			if(key != 'multiple' && key != 'value'){
+				var recipientType = parseInt(attendees[key]['display_type'], 10);
+				if(recipientType === DT_EQUIPMENT || recipientType === DT_ROOM) {
+					// Check whether we need to add an extra semicolon at the end
+					if(!isLastRecipientClosedWithSemicolon(dhtml.getElementById('bcc').value)){
+						dhtml.getElementById('bcc').value += '; ';
+					}
+					dhtml.getElementById('bcc').value += attendees[key].value + '; ';
+				} else {
+					// Check whether we need to add an extra semicolon at the end
+					if(!isLastRecipientClosedWithSemicolon(dhtml.getElementById('to').value)){
+						dhtml.getElementById('to').value += '; ';
+					}
+					dhtml.getElementById('to').value += attendees[key].value + '; ';
+				}
+			}
+		}
+	} else {
+		// this is not going to happen as we always use multiple recipients in meeting request dialog
+		var recipientType = parseInt(attendees['display_type'], 10);
+		if(recipientType === DT_EQUIPMENT || recipientType === DT_ROOM) {
+			// Check whether we need to add an extra semicolon at the end
+			if(!isLastRecipientClosedWithSemicolon(dhtml.getElementById('bcc').value)){
+				dhtml.getElementById('bcc').value += '; ';
+			}
+			dhtml.getElementById('bcc').value += attendees.value + '; ';
+		} else {
+			// Check whether we need to add an extra semicolon at the end
+			if(!isLastRecipientClosedWithSemicolon(dhtml.getElementById('to').value)){
+				dhtml.getElementById('to').value += '; ';
+			}
+			dhtml.getElementById('to').value += attendees.value + '; ';
+		}
+	}
+
 	syncRecipientFields(true);
 }
 
@@ -1751,4 +1794,4 @@ function appointmentItemSendMRMailConfirmation_callback(moduleObject, sendRespon
 		}
 	}
 	window.close();
-}
\ No newline at end of file
+}
