@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -456,7 +456,7 @@ function attachItemRenderRowColumnData(moduleObject, itemData, properties) {
 					value = strftime(_("%a %x %X"), xmlValue);
 				} else if(xmlNode && xmlNode.getAttribute("type") == "timestamp_date") {
 					value = strftime_gmt(_("%a %x %X"), xmlValue);
-				} else if(typeof xmlValue != null) {
+				} else if(typeof xmlValue == 'string') {
 					value = xmlValue.htmlEntities();
 				} else {
 					value = NBSP;
