@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -670,6 +670,11 @@ function showHideRecurrenceMenu(hide) {
 
 function delete_task_item()
 {
+	if (dhtml.getElementById("messagechanged").value == 1) {
+		if( confirm("This item has changed. Are you sure you want to delete it?") == false)
+			return;
+	}
+
 	if (module.messageentryid) {
 		var taskstate = dhtml.getElementById("taskstate").value;
 		var complete = dhtml.getElementById("complete").value;
@@ -684,7 +689,10 @@ function delete_task_item()
 		} else {
 			module.deleteMessage(false);
 		}
+	} else {
+		window.close();
 	}
+
 }
 
 function showTaskRecurrence()
@@ -834,4 +842,4 @@ function eventTaskWorkChange(moduleObject, element, event)
 	function convertToWeeks(days) {
 		element.value = Math.round((days/5)*10)/10 +" "+ (days/5 == 1 ? _("week") : _("weeks"));
 	}
-}
\ No newline at end of file
+}
