@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -109,7 +109,14 @@
 							<table id="form_fields">
 								<tr>
 									<th><label for="username"><?=_("Name")?>:</label></th>
-									<td><input type="text" name="username" id="username" class="inputelement" <?=($user)?'value="'.$user.'"':''?>></td>
+									<td><input type="text" name="username" id="username" class="inputelement"
+									<?php
+									 if (defined("CERT_VAR_TO_COMPARE_WITH") && $_SERVER ) {
+										echo " value='".$_SERVER[CERT_VAR_TO_COMPARE_WITH]."' readonly='readonly'";
+									 } elseif ($user) {
+									 	echo " value='".$user."'";
+									 }
+									?>></td>
 								</tr>
 								<tr>
 									<th><label for="password"><?=_("Password")?>:</label></th>
