@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -383,12 +383,17 @@ appointmentitemmodule.prototype.deleteMessage = function (basedate)
 		var end = dhtml.getElementById("duedate").getAttribute("unixtime");
 		var endtime = new Date(end * 1000);
 		
-		if (meeting !== 0 && (endtime.getTime() > (new Date().getTime()))) {
+		if (meeting !== 0 && !isMeetingInPast(endtime) && !isMeetingCanceled(this.itemProps)) {
 			/**
 			 * if occurrence is later then send confirmation message for cancellation message.
 			 * Check whether there are any recepients/resource in MR or not.
 			 */
 			if (isMeetingOrganized && this.itemProps.requestsent && this.itemProps.requestsent == "1") {
+				/**
+				 * with FF6 and above we have a problem of focus if a confirm box is called from parentwidow 
+				 * when another dialog is opened, so to get the focus back to correct window/dialog we do this call
+				 */
+				window.focus();
 				send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
 			} else if (!isMeetingOrganized){
 				sendConfirmationDeleteAppointmentItem(this, this.itemProps["subject"], basedate);
@@ -434,7 +439,7 @@ appointmentitemmodule.prototype.deleteMessage = function (basedate)
 		var endtime = new Date(end * 1000);
 
 		// if recurrence is later then send confirmation message for cancellation message.
-		if(meeting !== 0 && endtime.getTime() > (new Date().getTime())) {
+		if(meeting !== 0 && !isMeetingInPast(endtime) && !isMeetingCanceled(this.itemProps)) {
 			// Check whether there are any recepients in MR or not.
 			if (isMeetingOrganized && this.itemProps.requestsent && this.itemProps.requestsent == "1" ) {
 				send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
@@ -532,7 +537,8 @@ appointmentitemmodule.prototype.save = function(props, send, recipients, dialog_
 			data["recipients"]["recipient"].unshift({
 				"address": this.owner["email_address"],
 				"name": this.owner["fullname"],
-				"type": "mapi_to"
+				"type": "mapi_to",
+				"recipient_flags": 3 /* recipSenable | recipOrganizer */
 			});
 		}
 	}
