@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -378,6 +378,8 @@ appointmentlistmodule.prototype.deleteAppointment = function(entryid, basedate,
 	var selectedElement = dhtml.getElementById(elementId);
 	var send = false;
 
+	var appointmentItem = this.itemProps[entryid];
+
 	if(basedate) {
 		//occurrence end date
 		var end = (selectedElement.end)? selectedElement.end: (selectedElement.getAttribute("end"))? selectedElement.getAttribute("end"): (selectedElement.getAttribute("duedate"))? selectedElement.getAttribute("duedate") : selectedElement.duedate;
@@ -392,10 +394,15 @@ appointmentlistmodule.prototype.deleteAppointment = function(entryid, basedate,
 		 */
 		if(endtime.getTime() > (new Date().getTime()) && selectedElement.requestsent && selectedElement.requestsent == "1") {
 			if(selectedElement.meetingrequest && parseInt(selectedElement.meetingrequest, 10) == 1) {
+				/**
+				 * with FF6 and above we have a problem of focus if a confirm box is called from parentwidow 
+				 * when another dialog is opened, so to get the focus back to correct window/dialog we do this call
+				 */
+				window.focus();
 				send = confirm(_("Would you like to send an update to the attendees regarding cancellation of this meeting?"));
 				//if user does not want to cancel/delete the meeting,we want like to ignore this action
 				if(send == false) return true;
-			} else if (selectedElement.meetingrequest && parseInt(selectedElement.meetingrequest, 10) != 0) {
+			} else if (selectedElement.meetingrequest && parseInt(selectedElement.meetingrequest, 10) != 0 && !isMeetingCanceled(appointmentItem)) {
 				sendConfirmationDeleteAppointmentList(this, selectedElement, basedate);
 				return true;
 			}
@@ -441,7 +448,7 @@ appointmentlistmodule.prototype.deleteAppointment = function(entryid, basedate,
 				send = confirm(_("Would you like to send an update to the attendees regarding cancellation of this meeting?"));
 				//if user does not want to cancel/delete the meeting,we want like to ignore this action
 				if(send == false) return true;
-			} else if (selectedElement.meetingrequest && parseInt(selectedElement.meetingrequest, 10) != 0) {
+			} else if (selectedElement.meetingrequest && parseInt(selectedElement.meetingrequest, 10) != 0 && !isMeetingCanceled(appointmentItem)) {
 				sendConfirmationDeleteAppointmentList(this, selectedElement, false);
 				return true;
 			}
@@ -488,6 +495,8 @@ appointmentlistmodule.prototype.deleteAppointments = function(messages, promptoc
 	var messageClass = false;
 	var classNames = itemEl.className.split(" ");
 	var entryid = this.entryids[itemEl.id];
+	
+	var appointmentItem = this.itemProps[entryid];
 
 	//basedate for normal meetings is set as '0' i.e basedate doesn't exist, typecast it to integer so that later is doesn't break any IF statement
 	var basedate = itemEl.attributes["basedate"] ? parseInt(itemEl.attributes["basedate"].value, 10) : false;
@@ -520,7 +529,7 @@ appointmentlistmodule.prototype.deleteAppointments = function(messages, promptoc
 				// don't ask for meeting requests which are occuring in past
 				send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
 				deleteMessage = false;
-			} else if (MRResponseStatusOrganizer != olResponseNone && MRResponseStatusOrganizer != olResponseOrganized) {	//its attendee
+			} else if (MRResponseStatusOrganizer != olResponseNone && MRResponseStatusOrganizer != olResponseOrganized && !isMeetingCanceled(appointmentItem)) {	//its attendee
 				sendConfirmationDeleteAppointmentList(this, itemEl, false, softDelete);
 				return true;
 			}
