@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -1107,9 +1107,13 @@ ItemModule.prototype.setRecipients = function(message, actionType)
 	    var element = dhtml.getElementById(type);
 	    
 	    if(element){
-			element.value += elemdata[type].join("; ");
-			// make unique them again, this will eliminate the duplicate contacts in to/cc feilds (if any)
-			element.value = uniqueArray(element.value.split("; ")).join("; ");
+			if(elemdata[type].length > 0){
+				element.value += elemdata[type].join("; ");
+				// make unique them again, this will eliminate the duplicate contacts in to/cc feilds (if any)
+				element.value = uniqueArray(element.value.split("; ")).join("; ");
+				// Adding semicolon at the end, ready to go for the next recipient
+				element.value += ';';
+			}
 
 			/**
 			 * When new mail dialog is loaded we should fire change event 
@@ -1515,6 +1519,8 @@ ItemModule.prototype.retrieveInlineImagesFromBody = function (editorDocument)
 
 			var contentId = src.substr(src.indexOf("attachCid=")+10);
 			contentId = contentId.substring(0, contentId.indexOf("&"));
+			// Decode the CID so it will match the unencoded data in the inlineattachments array
+			contentId = decodeURIComponent(contentId);
 			
 			for (var attach_Num in this.inlineattachments) {
 				if (contentId == this.inlineattachments[attach_Num]["cid"]){
@@ -1784,26 +1790,25 @@ function eventItemAttachmentNameAddInlineClick(moduleObject, element, event)
 function eventAttachmentClick(moduleObject, element, event)
 {
 	var attach_num = element.getAttribute("attach_num", false);
-	var attachments = (moduleObject.itemProps && moduleObject.itemProps.attachments) ? moduleObject.itemProps.attachments.attachment : false;
-	/**
-	 * When an attachment is clicked in an edit dialog, there is also the possibility that the 
-	 * attachment has not been saved at the server yet. So therefor we need add the list of unsaved 
-	 * new attachments as well.
-	 */
-	if(!attachments && moduleObject.attachments){
+	var attachments = (moduleObject.itemProps && moduleObject.itemProps.attachments) ? moduleObject.itemProps.attachments.attachment : new Array();
+	if(attachments.length === 0 && moduleObject.attachments){
 		// clone array
-		attachments = new Array();
 		for(var i in moduleObject.attachments){
 			attachments[i] = new Object();
 			for(var j in moduleObject.attachments[i]){
 				attachments[i][j] = moduleObject.attachments[i][j];
 			}
 		}
+	}
 
-		if(moduleObject.newattachments){
-			for(var i in moduleObject.newattachments){
-				attachments[attachments.length] = moduleObject.newattachments[i];
-			}
+	/**
+	 * When an attachment is clicked in an edit dialog, there is also the possibility that the 
+	 * attachment has not been saved at the server yet. So therefor we need add the list of unsaved 
+	 * new attachments as well.
+	 */
+	if(moduleObject.newattachments){
+		for(var i in moduleObject.newattachments){
+			attachments[attachments.length] = moduleObject.newattachments[i];
 		}
 	}
 
@@ -1869,8 +1874,8 @@ function eventAttachmentClick(moduleObject, element, event)
 			} else {
 				attachNum += "&attachNum[]=" + attach_num;
 				var action = webclient.base_url + "index.php?load=download_attachment&store=" + moduleObject.storeid + attachNum + "&openType=attachment";
-				if(moduleObject.rootentryid) {
-					action += "&entryid=" + moduleObject.rootentryid;
+				if(moduleObject.messageentryid) {
+					action += "&entryid=" + moduleObject.messageentryid;
 				}
 
 				/**
