@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -79,6 +79,9 @@ ruleslistmodule.prototype.init = function(id, element, title, data)
 	
 	this.events["rowcolumn"]["rule_state"] = new Object();
 	this.events["rowcolumn"]["rule_state"]["click"] = eventListChangeCompleteStatus;
+
+	// remove column events, to disable sorting on columns
+	delete this.events["column"];
 }
 
 // the only reason we override the execute function is that we want to both
