@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -113,7 +113,7 @@ foreach($translations as $domain => $translation_list){
 	}
 }
 ?>
-		if(typeof domain != "string") domain = "zarafa";
+		if(typeof domain != "string") domain = "zarafa_webaccess";
 		if(typeof translations[domain] == "undefined") return key;
 
 		if(translations[domain][key]) {
@@ -131,4 +131,4 @@ foreach($translations as $domain => $translation_list){
  * @param string key english text
  * @return string translated text
  */
-function dgettext(domain, key){ return _(key, domain); }
\ No newline at end of file
+function dgettext(domain, key){ return _(key, domain); }
