@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -111,7 +111,7 @@ QuotaWidget.prototype.update = function(size, warn, soft, hard)
 	}
 
 	if(maxLimit > 0) {
-		if(warn <= soft) {
+		if(warnSize <= softSize) {
 			quota.push({
 				qoutaname: "warn",
 				size: warnSize,
@@ -129,7 +129,7 @@ QuotaWidget.prototype.update = function(size, warn, soft, hard)
 				size: hardSize,
 				element: this.hardElement
 			});
-		} else if(soft < warn) {
+		} else if(softSize < warnSize) {
 			quota.push({
 				qoutaname: "soft",
 				size: softSize,
