@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -363,7 +363,7 @@ TableWidget.prototype.generateRowColumnsHTML = function(rowData, addWidthData){
 					columnWidth = ' style="width:'+this.widths[ this.columns[i]['id'] ]+'px;" ';
 				}
 
-				content += '<td class="rowcolumn '+cellClassnames+'" '+columnWidth+'></td>';
+				content += '<td class="rowcolumn '+cellClassnames+'" '+columnWidth+' columnID="'+this.columns[i]["id"]+'"></td>';
 			}
 		}else{
 			content += '<td></td>';
