@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -217,7 +217,7 @@
 			
 			$rows = mapi_table_queryallrows($contents, array(PR_ENTRYID), $restriction);
 			
-			if(count($rows) == 0) {
+			if(empty($rows)) {
 				// None found, create one if possible
 				if(!$create)
 					return false;
@@ -715,7 +715,8 @@
 			$rows = mapi_table_queryallrows($table, array(PR_ATTACH_NUM));
 			
 			// Assume only one attachment
-			if(count($rows) < 1) return false;
+			if(empty($rows))
+				return false;
 			
 			$attach = mapi_message_openattach($message, $rows[0][PR_ATTACH_NUM]);
 			$message = mapi_openproperty($attach, PR_ATTACH_DATA_OBJ, IID_IMessage, 0, 0);
@@ -746,7 +747,7 @@
 			$recipTable = mapi_message_getrecipienttable($this->message);
 			$recips = mapi_table_queryallrows($recipTable, array(PR_DISPLAY_NAME));
 
-			if (count($recips) > 0) {
+			if (!empty($recips)) {
 				$owner = array();
 				foreach ($recips as $value) {
 					$owner[] = $value[PR_DISPLAY_NAME];
@@ -804,7 +805,7 @@
 				$recips[] = $assignor;
 			}
 
-			if (count($recips) > 0)
+			if (!empty($recips))
 				mapi_message_modifyrecipients($task, MODRECIP_ADD, $recips);
 		}
 
@@ -849,7 +850,7 @@
 			$rows = mapi_table_queryallrows($contents, array(PR_ENTRYID, PR_PARENT_ENTRYID, PR_STORE_ENTRYID), $restriction);
 
 			$taskrequest = false;
-			if(count($rows) > 0) {
+			if(!empty($rows)) {
 				// If there are multiple, just use the first
 				$entryid = $rows[0][PR_ENTRYID];
 				$wastebasket = mapi_msgstore_openentry($store, $storeProps[PR_IPM_WASTEBASKET_ENTRYID]);
@@ -898,7 +899,8 @@
 												));
 
 				// No recipients found, return error
-				if (count($recips) == 0) return false;
+				if (empty($recips))
+					return false;
 
 				foreach($recips as $recip) {
 					$recip[PR_RECIPIENT_TYPE] = MAPI_TO;	// Change recipient type to MAPI_TO
@@ -926,39 +928,39 @@
 			$msgProps = mapi_getprops($this->message);
 			$body = "";
 
-			if (isset($msgProps[PR_SUBJECT])) $body .= "\n" . _("Subject") . ":\t". $msgProps[PR_SUBJECT];
-			if (isset($msgProps[$this->props['startdate']])) $body .= "\n" . _("Start Date") . ":\t". strftime("%A, %B %d, %Y",$msgProps[$this->props['startdate']]);
-			if (isset($msgProps[$this->props['duedate']])) $body .= "\n" . _("Due Date") . ":\t". strftime("%A, %B %d, %Y",$msgProps[$this->props['duedate']]);
+			if (isset($msgProps[PR_SUBJECT])) $body .= "\n" . dgettext("zarafa","Subject") . ":\t". $msgProps[PR_SUBJECT];
+			if (isset($msgProps[$this->props['startdate']])) $body .= "\n" . dgettext("zarafa","Start Date") . ":\t". strftime(dgettext("zarafa","%A, %B %d, %Y"),$msgProps[$this->props['startdate']]);
+			if (isset($msgProps[$this->props['duedate']])) $body .= "\n" . dgettext("zarafa","Due Date") . ":\t". strftime(dgettext("zarafa","%A, %B %d, %Y"),$msgProps[$this->props['duedate']]);
 			$body .= "\n";
 
 			if (isset($msgProps[$this->props['status']])) {
-				$body .= "\n" . _("Status") . ":\t";
-				if ($msgProps[$this->props['status']] == 0) $body .= _("Not Started");
-				else if ($msgProps[$this->props['status']] == 1) $body .= _("In Progress");
-				else if ($msgProps[$this->props['status']] == 2) $body .= _("Complete");
-				else if ($msgProps[$this->props['status']] == 3) $body .= _("Wait for other person");
-				else if ($msgProps[$this->props['status']] == 4) $body .= _("Deferred");
+				$body .= "\n" . dgettext("zarafa","Status") . ":\t";
+				if ($msgProps[$this->props['status']] == 0) $body .= dgettext("zarafa","Not Started");
+				else if ($msgProps[$this->props['status']] == 1) $body .= dgettext("zarafa","In Progress");
+				else if ($msgProps[$this->props['status']] == 2) $body .= dgettext("zarafa","Complete");
+				else if ($msgProps[$this->props['status']] == 3) $body .= dgettext("zarafa","Wait for other person");
+				else if ($msgProps[$this->props['status']] == 4) $body .= dgettext("zarafa","Deferred");
 			}
 
 			if (isset($msgProps[$this->props['percent_complete']])) {
-				$body .= "\n" . _("Percent Complete") . ":\t". ($msgProps[$this->props['percent_complete']] * 100).'%';
+				$body .= "\n" . dgettext("zarafa","Percent Complete") . ":\t". ($msgProps[$this->props['percent_complete']] * 100).'%';
 
 				if ($msgProps[$this->props['percent_complete']] == 1 && isset($msgProps[$this->props['datecompleted']]))
-					$body .= "\n" . _("Date Completed") . ":\t". strftime("%A, %B %d, %Y",$msgProps[$this->props['datecompleted']]);
+					$body .= "\n" . dgettext("zarafa","Date Completed") . ":\t". strftime("%A, %B %d, %Y",$msgProps[$this->props['datecompleted']]);
 			}
 			$body .= "\n";
 
-			if (isset($msgProps[$this->props['totalwork']])) $body .= "\n" . _("Total Work") . ":\t". ($msgProps[$this->props['totalwork']]/60) ." " . _("hours");
-			if (isset($msgProps[$this->props['actualwork']])) $body .= "\n" . _("Actual Work") . ":\t". ($msgProps[$this->props['actualwork']]/60) ." " . _("hours");
+			if (isset($msgProps[$this->props['totalwork']])) $body .= "\n" . dgettext("zarafa","Total Work") . ":\t". ($msgProps[$this->props['totalwork']]/60) ." " . dgettext("zarafa","hours");
+			if (isset($msgProps[$this->props['actualwork']])) $body .= "\n" . dgettext("zarafa","Actual Work") . ":\t". ($msgProps[$this->props['actualwork']]/60) ." " . dgettext("zarafa","hours");
 			$body .="\n";
 
-			if (isset($msgProps[$this->props['owner']])) $body .= "\n" . _("Owner") . ":\t". $msgProps[$this->props['owner']];
+			if (isset($msgProps[$this->props['owner']])) $body .= "\n" . dgettext("zarafa","Owner") . ":\t". $msgProps[$this->props['owner']];
 			$body .="\n";
 
-			if (isset($msgProps[$this->props['categories']]) && count($msgProps[$this->props['categories']]) > 0) $body .= "\nCategories:\t". implode(', ', $msgProps[$this->props['categories']]);
-			if (isset($msgProps[$this->props['companies']]) && count($msgProps[$this->props['companies']]) > 0) $body .= "\nCompany:\t". implode(', ', $msgProps[$this->props['companies']]);
-			if (isset($msgProps[$this->props['billinginformation']])) $body .= "\n" . _("Billing Information") . ":\t". $msgProps[$this->props['billinginformation']];
-			if (isset($msgProps[$this->props['mileage']])) $body .= "\n" . _("Mileage") . ":\t". $msgProps[$this->props['mileage']];
+			if (isset($msgProps[$this->props['categories']]) && !empty($msgProps[$this->props['categories']])) $body .= "\nCategories:\t". implode(', ', $msgProps[$this->props['categories']]);
+			if (isset($msgProps[$this->props['companies']]) && !empty($msgProps[$this->props['companies']])) $body .= "\nCompany:\t". implode(', ', $msgProps[$this->props['companies']]);
+			if (isset($msgProps[$this->props['billinginformation']])) $body .= "\n" . dgettext("zarafa","Billing Information") . ":\t". $msgProps[$this->props['billinginformation']];
+			if (isset($msgProps[$this->props['mileage']])) $body .= "\n" . dgettext("zarafa","Mileage") . ":\t". $msgProps[$this->props['mileage']];
 			$body .="\n";
 
 			$content = mapi_message_openproperty($this->message, PR_BODY);
