@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -418,7 +418,18 @@ define('olResponseTentative'                     ,2);
 define('olResponseAccepted'                      ,3);
 define('olResponseDeclined'                      ,4);
 define('olResponseNotResponded'                  ,5);
-    
+
+/* OlRecipientTrackStatus to set PR_RECIPIENT_TRACKSTATUS in recipient table
+ * Value of the recipient trackstatus are same as OlResponseStatus but
+ * recipient trackstatus doesn't have olResponseOrganized and olResponseNotResponded
+ * and olResponseNone has different interpretation with PR_RECIPIENT_TRACKSTATUS
+ * so to avoid confusions we have defined new constants.
+*/
+define('olRecipientTrackStatusNone'              ,0);
+define('olRecipientTrackStatusTentative'         ,2);
+define('olRecipientTrackStatusAccepted'          ,3);
+define('olRecipientTrackStatusDeclined'          ,4);
+
 /* OlMeetingStatus */
 define('olNonMeeting'                            ,0);
 define('olMeeting'                               ,1);
@@ -491,6 +502,12 @@ define("ZARAFA_STORE_PUBLIC_GUID"                ,makeGuid("{D47F4A09-D3BD-493C-
 define("ZARAFA_STORE_DELEGATE_GUID"              ,makeGuid("{7C7C1085-BC6D-4E53-9DAB-8A53F8DEF808}"));    // other store
 define('ZARAFA_STORE_ARCHIVER_GUID'              ,makeGuid("{BC8953AD-2E3F-4172-9404-896FF459870F}"));    // archive store
 
+/* global profile section guid */
+define('pbGlobalProfileSectionGuid'              ,makeGuid("{C8B0DB13-05AA-1A10-9BB0-00AA002FC45A}"));
+
+/* Zarafa Contacts provider GUID */
+define('ZARAFA_CONTACTS_GUID'                    ,makeGuid("{30047F72-92E3-DA4F-B86A-E52A7FE46571}"));
+
 /* Permissions */
 
 // Get permission type
@@ -629,4 +646,18 @@ define('mtgDelegatorCopy',						0x00100000);	// This is set on the delegator's c
 define('MAPI_ONE_OFF_UNICODE',					0x8000);		// the flag that defines whether the embedded strings are Unicode in one off entryids.
 define('MAPI_ONE_OFF_NO_RICH_INFO',				0x0001);		// the flag that specifies whether the recipient gets TNEF or not.
 
+/* Mask flags for mapi_msgstore_advise */
+define('fnevCriticalError',           0x00000001);
+define('fnevNewMail',                 0x00000002);
+define('fnevObjectCreated',           0x00000004);
+define('fnevObjectDeleted',           0x00000008);
+define('fnevObjectModified',          0x00000010);
+define('fnevObjectMoved',             0x00000020);
+define('fnevObjectCopied',            0x00000040);
+define('fnevSearchComplete',          0x00000080);
+define('fnevTableModified',           0x00000100);
+define('fnevStatusObjectModified',    0x00000200);
+define('fnevReservedForMapi',         0x40000000);
+define('fnevExtended',                0x80000000);
+
 ?>
\ No newline at end of file
