@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -59,6 +59,10 @@
 	 */
 	class ContactItemModule extends ItemModule
 	{
+		/**
+		 * @var Array properties of contact item that will be used to get data
+		 */
+		var $properties = null;
 
 		var $plaintext;
 
@@ -69,8 +73,6 @@
 		 */
 		function ContactItemModule($id, $data)
 		{
-			$this->properties = $GLOBALS["properties"]->getContactProperties();
-			
 			$this->plaintext = true;
 
 			parent::ItemModule($id, $data);
@@ -452,6 +454,19 @@
 			if($result) {
 				$GLOBALS["bus"]->notify(bin2hex($parententryid), TABLE_DELETE, $props);
 			}
-		}	
+		}
+
+		/**
+		 * Function will generate property tags based on passed MAPIStore to use
+		 * in module. These properties are regenerated for every request so stores
+		 * residing on different servers will have proper values for property tags.
+		 * @param MAPIStore $store store that should be used to generate property tags.
+		 * @param Binary $entryid entryid of message/folder
+		 * @param Array $action action data sent by client
+		 */
+		function generatePropertyTags($store, $entryid, $action)
+		{
+			$this->properties = $GLOBALS["properties"]->getContactProperties($store);
+		}
 	}
 ?>
\ No newline at end of file
