@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -55,6 +55,11 @@
 	 */
 	class ContactListModule extends ListModule
 	{
+		/**
+		 * @var Array properties of contact item that will be used to get data
+		 */
+		var $properties = null;
+
 		/**
 		 * Constructor
 		 * @param int $id unique id.
@@ -62,15 +67,10 @@
 		 */
 		function ContactListModule($id, $data)
 		{
-			$this->properties = $GLOBALS["properties"]->getContactProperties();
-
 			$this->tablecolumns = $GLOBALS["TableColumns"]->getContactListTableColumns();
 
 			parent::ListModule($id, $data, array(OBJECT_SAVE, TABLE_SAVE, TABLE_DELETE));
 
-			$this->sort = array();
-			$this->sort[$this->properties["fileas"]] = TABLE_SORT_ASCEND;
-			
 			$this->start = 0;
 		}
 
@@ -89,6 +89,8 @@
 					$parententryid = $this->getActionParentEntryID($action);
 					$entryid = $this->getActionEntryID($action);
 
+					$this->generatePropertyTags($store, $entryid, $action);
+
 					switch($action["attributes"]["type"])
 					{
 						case "list":
@@ -310,6 +312,9 @@
 					$data["sort"]["attributes"]["direction"] = (isset($this->sort[$firstSortColumn]) && $this->sort[$firstSortColumn] == TABLE_SORT_ASCEND) ? "asc" : "desc";
 					$data["sort"]["_content"] = array_search($firstSortColumn, $this->properties);
 
+					if(isset($this->selectedMessageId)) {
+						$this->start = $GLOBALS["operations"]->getStartRow($store, $entryid, $this->selectedMessageId, $this->sort, false, $this->searchRestriction);
+					}
 					$items = array_merge($data, $GLOBALS["operations"]->getTable($store, $entryid, $this->properties, $sort, $this->start, false, $restriction));
 					
 					for($i=0; $i<count($items["item"]); $i++){
@@ -335,9 +340,12 @@
 		function parseSearchRestriction($action)
 		{
 			if(isset($action["restriction"])) {
-				if(isset($action["restriction"]["start"])) {
+				if(isset($action["restriction"]["selectedmessageid"])) {
+					$this->selectedMessageId = hex2bin($action["restriction"]["selectedmessageid"]);
+				} elseif(isset($action["restriction"]["start"])) {
 					// Set start variable
 					$this->start = (int) $action["restriction"]["start"];
+					unset($this->selectedMessageId);
 				}
 
 				if(isset($action["restriction"]["search"])) {
@@ -434,5 +442,21 @@
 				}
 			}
 		}
+
+		/**
+		 * Function will generate property tags based on passed MAPIStore to use
+		 * in module. These properties are regenerated for every request so stores
+		 * residing on different servers will have proper values for property tags.
+		 * @param MAPIStore $store store that should be used to generate property tags.
+		 * @param Binary $entryid entryid of message/folder
+		 * @param Array $action action data sent by client
+		 */
+		function generatePropertyTags($store, $entryid, $action)
+		{
+			$this->properties = $GLOBALS["properties"]->getContactProperties($store);
+
+			$this->sort = array();
+			$this->sort[$this->properties["fileas"]] = TABLE_SORT_ASCEND;
+		}
 	}
-?>
\ No newline at end of file
+?>
