@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -57,6 +57,11 @@
 	 */
 	class CreateMailItemModule extends ItemModule
 	{
+		/**
+		 * @var Array properties of mail item that will be used to get data
+		 */
+		var $properties = null;
+
 		/**
 		 * Constructor
 		 * @param int $id unique id.
@@ -64,8 +69,6 @@
 		 */
 		function CreateMailItemModule($id, $data)
 		{
-			$this->properties = $GLOBALS["properties"]->getMailProperties();
-			
 			parent::ItemModule($id, $data);
 		}
 		
@@ -375,5 +378,18 @@
 			
 			return $result;
 		}
+
+		/**
+		 * Function will generate property tags based on passed MAPIStore to use
+		 * in module. These properties are regenerated for every request so stores
+		 * residing on different servers will have proper values for property tags.
+		 * @param MAPIStore $store store that should be used to generate property tags.
+		 * @param Binary $entryid entryid of message/folder
+		 * @param Array $action action data sent by client
+		 */
+		function generatePropertyTags($store, $entryid, $action)
+		{
+			$this->properties = $GLOBALS["properties"]->getMailProperties($store);
+		}
 	}
 ?>
