@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -57,6 +57,11 @@
 	 */
 	class DistListModule extends ListModule
 	{
+		/**
+		 * @var Array properties of distribution list item that will be used to get data
+		 */
+		var $properties = null;
+
 		var $plaintext;
 
 		/**
@@ -66,8 +71,6 @@
 		 */
 		function DistListModule($id, $data)
 		{
-			$this->properties = $GLOBALS["properties"]->getDistListProperties();
-
 			$this->tablecolumns = $GLOBALS["TableColumns"]->getDistListTableColumns();
 
 			$this->plaintext = true;
@@ -91,6 +94,8 @@
 				$parententryid = $this->getActionParentEntryID($action);
 				$entryid = $this->getActionEntryID($action);
 
+				$this->generatePropertyTags($store, $entryid, $action);
+
 				switch($action["attributes"]["type"]) {
 					case 'list':
 						$result = $this->item($store, $entryid, $action);
@@ -340,5 +345,17 @@
 
 		}
 
+		/**
+		 * Function will generate property tags based on passed MAPIStore to use
+		 * in module. These properties are regenerated for every request so stores
+		 * residing on different servers will have proper values for property tags.
+		 * @param MAPIStore $store store that should be used to generate property tags.
+		 * @param Binary $entryid entryid of message/folder
+		 * @param Array $action action data sent by client
+		 */
+		function generatePropertyTags($store, $entryid, $action)
+		{
+			$this->properties = $GLOBALS["properties"]->getDistListProperties($store);
+		}
 	}
 ?>
