@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -158,7 +158,9 @@
 					$store = $this->getActionStore($action);
 					$parententryid = $this->getActionParentEntryID($action);
 					$entryid = $this->getActionEntryID($action);
-				
+
+					$this->generatePropertyTags($store, $entryid, $action);
+
 					switch($action["attributes"]["type"])
 					{
 						case "list":
@@ -291,6 +293,10 @@
 				 */
 				$data["sort"]["_content"] = array_search($firstSortColumn &~ MV_INSTANCE, $this->properties);
 
+				if(isset($this->selectedMessageId)) {
+					$this->start = $GLOBALS["operations"]->getStartRow($store, $entryid, $this->selectedMessageId, $this->sort, false, $this->searchRestriction);
+				}
+
 				// Get the table and merge the arrays
 				$items = $GLOBALS["operations"]->getTable($store, $entryid, $this->properties, $this->sort, $this->start, false, $this->searchRestriction);
 				
@@ -699,9 +705,12 @@
 		function parseSearchRestriction($action)
 		{
 			if(isset($action["restriction"])) {
-				if(isset($action["restriction"]["start"])) {
+				if(isset($action["restriction"]["selectedmessageid"])) {
+					$this->selectedMessageId = hex2bin($action["restriction"]["selectedmessageid"]);
+				} elseif(isset($action["restriction"]["start"])) {
 					// Set start variable
 					$this->start = (int) $action["restriction"]["start"];
+					unset($this->selectedMessageId);
 				}
 			}
 		}
@@ -774,11 +783,6 @@
 						}
 					}
 				}
-				// adding selected message ID to sort array so we can return the particular item to 
-				// client while displaying the items in table
-				if(isset($action["sort"]["selectedmessageid"]) && $action["sort"]["selectedmessageid"]!= ""){
-					$this->sort["selectedmessageid"] = $action["sort"]["selectedmessageid"];
-				}
 			}
 			
 		}
@@ -1156,7 +1160,14 @@
 		 * @param object $store MAPI Message Store Object
 		 */
 		function getDelegateFolderInfo($store)
-		{	
+		{
+			$this->localFreeBusyFolder = false;
+
+			if(!(isset($store) && $store)) {
+				// only continue if store is passed
+				return;
+			}
+
 			$this->storeProviderGuid = mapi_getprops($store, array(PR_MDB_PROVIDER));
 
 			// open localfreebusy folder for delegate permissions
