@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -65,6 +65,11 @@
 		 */
 		var $sentcolumns;
 
+		/**
+		 * @var Array properties of mail item that will be used to get data
+		 */
+		var $properties = null;
+
 		/**
 		 * Constructor
 		 * @param int $id unique id.
@@ -72,8 +77,6 @@
 		 */
 		function MailListModule($id, $data)
 		{
-			$this->properties = $GLOBALS["properties"]->getMailProperties();
-
 			// Default Columns
 			$this->tablecolumns = $GLOBALS["TableColumns"]->getMailListTableColumns();
 
@@ -119,6 +122,8 @@
 					$parententryid = $this->getActionParentEntryID($action);
 					$entryid = $this->getActionEntryID($action);
 
+					$this->generatePropertyTags($store, $entryid, $action);
+
 					switch($action["attributes"]["type"])
 					{
 						case "list":
@@ -253,9 +258,12 @@
 			// TODO: let javascript generate the MAPI restriction just as with the rules
 
 			if(isset($action["restriction"])) {
-				if(isset($action["restriction"]["start"])) {
+				if(isset($action["restriction"]["selectedmessageid"])) {
+					$this->selectedMessageId = hex2bin($action["restriction"]["selectedmessageid"]);
+				} elseif(isset($action["restriction"]["start"])) {
 					// Set start variable
 					$this->start = (int) $action["restriction"]["start"];
+					unset($this->selectedMessageId);
 				}
 				if(isset($action["restriction"]["search"])) {
 					// if the restriction is a associative array, it means that only one property is requested
@@ -415,7 +423,11 @@
 			$data["storeid"]["_content"] = bin2hex($folderprops[PR_STORE_ENTRYID]);
 			$data["isinbox"] = array();
 			$data["isinbox"]["_content"] = $folderprops[PR_ENTRYID] == $inboxentryid;
-				
+
+			if(isset($this->selectedMessageId)) {
+				$this->start = $GLOBALS["operations"]->getStartRow($store, $entryid, $this->selectedMessageId, $this->sort, false, $this->searchRestriction);
+			}
+
 			// Get the table and merge the arrays
 			$items = array_merge($data, $GLOBALS["operations"]->getTable($store, $entryid, $this->properties, $this->sort, $this->start, false, $this->searchRestriction));
 
@@ -428,5 +440,18 @@
 			array_push($this->responseData["action"], $data);
 			$GLOBALS["bus"]->addData($this->responseData);
 		}
+
+		/**
+		 * Function will generate property tags based on passed MAPIStore to use
+		 * in module. These properties are regenerated for every request so stores
+		 * residing on different servers will have proper values for property tags.
+		 * @param MAPIStore $store store that should be used to generate property tags.
+		 * @param Binary $entryid entryid of message/folder
+		 * @param Array $action action data sent by client
+		 */
+		function generatePropertyTags($store, $entryid, $action)
+		{
+			$this->properties = $GLOBALS["properties"]->getMailProperties($store);
+		}
 	}
-?>
\ No newline at end of file
+?>
