@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -184,7 +184,7 @@
 		 * @param boolean $success operation completed successfully or not
 		 * @param string $message the error message which will be shown to client on any failure of operation
 		 */
-		function sendFeedback($success = false, $message = "", $addResponseDataToBus = true)
+		function sendFeedback($success = false, $message = "")
 		{
 			if($success == true) {
 				// Send success message to client
@@ -192,9 +192,7 @@
 				$data["attributes"] = array("type" => "success");
 
 				array_push($this->responseData["action"], $data);
-				if($addResponseDataToBus){
-					$GLOBALS["bus"]->addData($this->responseData);
-				}
+				$GLOBALS["bus"]->addData($this->responseData);
 			} else {
 				// send error message to client
 				$data = array();
@@ -203,9 +201,7 @@
 				$data["error"]["message"] = $message;
 				
 				array_push($this->responseData["action"], $data);
-				if($addResponseDataToBus){
-					$GLOBALS["bus"]->addData($this->responseData);
-				}
+				$GLOBALS["bus"]->addData($this->responseData);
 			}
 		}
 
