@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -56,6 +56,11 @@
 	
 	class PrintListModule extends ListModule
 	{
+		/**
+		 * @var Array properties of appointemnt item that will be used to get data
+		 */
+		var $properties = null;
+
 		/**
 		 * Constructor
 		 * @param int $id unique id.
@@ -63,16 +68,11 @@
 		 */
 		function PrintListModule($id, $data)
 		{
-			$this->properties = $GLOBALS["properties"]->getAppointmentProperties();
-
 			// tablecolumns of appointmentlistmodule is used here
 			$this->tablecolumns = $GLOBALS["TableColumns"]->getAppointmentListTableColumns();
 
 			parent::ListModule($id, $data);
 
-			$this->sort = array();
-			$this->sort[$this->properties["startdate"]] = TABLE_SORT_ASCEND;
-			
 			$this->start = 0;
 		}
 
@@ -212,5 +212,21 @@
 		   }
 		   return ($start_a < $start_b) ? -1 : 1;
 		}
+
+		/**
+		 * Function will generate property tags based on passed MAPIStore to use
+		 * in module. These properties are regenerated for every request so stores
+		 * residing on different servers will have proper values for property tags.
+		 * @param MAPIStore $store store that should be used to generate property tags.
+		 * @param Binary $entryid entryid of message/folder
+		 * @param Array $action action data sent by client
+		 */
+		function generatePropertyTags($store, $entryid, $action)
+		{
+			$this->properties = $GLOBALS["properties"]->getAppointmentProperties($store);
+
+			$this->sort = array();
+			$this->sort[$this->properties["startdate"]] = TABLE_SORT_ASCEND;
+		}
 	}
 ?>
