@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -58,6 +58,11 @@
 	*/
 	class ReminderListModule extends ListModule
 	{
+		/**
+		 * @var Array properties of reminder item that will be used to get data
+		 */
+		var $properties = null;
+
 		/**
 		* Constructor
 		* @param int $id unique id.
@@ -65,16 +70,11 @@
 		*/
 		function ReminderListModule($id, $data)
 		{
-			$this->properties = $GLOBALS["properties"]->getReminderProperties();
-		
 			// Default Columns
 			$this->tablecolumns = $GLOBALS["TableColumns"]->getReminderListTableColumns();
 
 			parent::ListModule($id, $data, array());
 
-			$this->sort = array();
-			$this->sort[$this->properties["remindertime"]] = TABLE_SORT_DESCEND;
-			
 			$store = $GLOBALS["mapisession"]->getDefaultMessageStore();
 			$this->reminderEntryId = $this->getReminderFolderEntryId($store);
 
@@ -88,6 +88,8 @@
 			$result = false;
 			foreach($this->data as $action)
 			{
+				$this->generatePropertyTags($store, false, $action);
+
 				if(isset($action["attributes"]) && isset($action["attributes"]["type"])) {
 					switch($action["attributes"]["type"])
 					{
@@ -273,8 +275,14 @@
 			);
 
 			$reminderfolder = mapi_msgstore_openentry($store, $this->reminderEntryId);
-			if(!$reminderfolder)
-				return false;
+			if(!$reminderfolder) {
+				if(mapi_last_hresult() == MAPI_E_NOT_FOUND) {
+					$this->reminderEntryId = $this->createReminderFolder($store);
+					$reminderfolder = mapi_msgstore_openentry($store, $this->reminderEntryId);
+				}				
+				if(!$reminderfolder)
+					return false;
+			}
 				
 			$remindertable = mapi_folder_getcontentstable($reminderfolder);
 			if(!$remindertable)
@@ -304,17 +312,17 @@
 					 */
 					$occurrences = $recur->getItems($row[$this->properties["flagdueby"]], time(), 0, true);
 
-					if(count($occurrences) == 0)
-						continue;
+					if(count($occurrences) > 1) {
+					    // More than one occurrence, use the last one instead of the first one after flagdueby
+                        $occ = $occurrences[count($occurrences)-1];
 
-					$occ = $occurrences[count($occurrences)-1];
-
-					// Bydefault, on occurrence reminder is true but if reminder value is set to false then we don't send popup reminder for this occurrence
-					if (!(isset($occ[$this->properties['reminder']]) && $occ[$this->properties['reminder']] == 0)) {
-						$row[$this->properties["remindertime"]] = $occ[$this->properties["appointment_startdate"]];
-						$row[$this->properties["appointment_startdate"]] = $occ[$this->properties["appointment_startdate"]];
-						$row[$this->properties["appointment_enddate"]] = $occ[$this->properties["appointment_startdate"]];
-					}
+                        // Bydefault, on occurrence reminder is true but if reminder value is set to false then we don't send popup reminder for this occurrence
+                        if (!(isset($occ[$this->properties['reminder']]) && $occ[$this->properties['reminder']] == 0)) {
+                            $row[$this->properties["remindertime"]] = $occ[$this->properties["appointment_startdate"]];
+                            $row[$this->properties["appointment_startdate"]] = $occ[$this->properties["appointment_startdate"]];
+                            $row[$this->properties["appointment_enddate"]] = $occ[$this->properties["appointment_startdate"]];
+                        }
+                    }
 				}
 
 				// Add the non-bogus rows
@@ -414,5 +422,21 @@
 			}
 			return $result;
 		}
+
+		/**
+		 * Function will generate property tags based on passed MAPIStore to use
+		 * in module. These properties are regenerated for every request so stores
+		 * residing on different servers will have proper values for property tags.
+		 * @param MAPIStore $store store that should be used to generate property tags.
+		 * @param Binary $entryid entryid of message/folder
+		 * @param Array $action action data sent by client
+		 */
+		function generatePropertyTags($store, $entryid, $action)
+		{
+			$this->properties = $GLOBALS["properties"]->getReminderProperties($store);
+
+			$this->sort = array();
+			$this->sort[$this->properties["remindertime"]] = TABLE_SORT_DESCEND;
+		}
 	}
 ?>
