@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -60,6 +60,11 @@ include_once("mapi/class.taskrequest.php");
 	 */
 	class TaskItemModule extends ItemModule
 	{
+		/**
+		 * @var Array properties of task item that will be used to get data
+		 */
+		var $properties = null;
+
 		var $plaintext;
 
 		/**
@@ -69,8 +74,6 @@ include_once("mapi/class.taskrequest.php");
 		 */
 		function TaskItemModule($id, $data)
 		{
-			$this->properties = $GLOBALS["properties"]->getTaskProperties();
-			
 			$this->plaintext = true;
 
 			parent::ItemModule($id, $data);
@@ -187,5 +190,18 @@ include_once("mapi/class.taskrequest.php");
 
 			return $result;
 		}
+
+		/**
+		 * Function will generate property tags based on passed MAPIStore to use
+		 * in module. These properties are regenerated for every request so stores
+		 * residing on different servers will have proper values for property tags.
+		 * @param MAPIStore $store store that should be used to generate property tags.
+		 * @param Binary $entryid entryid of message/folder
+		 * @param Array $action action data sent by client
+		 */
+		function generatePropertyTags($store, $entryid, $action)
+		{
+			$this->properties = $GLOBALS["properties"]->getTaskProperties($store);
+		}
 	}
 ?>
