@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -57,6 +57,11 @@
 	 */
 	class TaskListModule extends ListModule
 	{
+		/**
+		 * @var Array properties of task item that will be used to get data
+		 */
+		var $properties = null;
+
 		/**
 		 * Constructor
 		 * @param int $id unique id.
@@ -64,8 +69,6 @@
 		 */
 		function TaskListModule($id, $data)
 		{
-			$this->properties = $GLOBALS["properties"]->getTaskProperties();
-
 			$this->tablecolumns = $GLOBALS["TableColumns"]->getTaskListTableColumns();
 
 			/*
@@ -105,9 +108,6 @@
 
 			parent::ListModule($id, $data, array(OBJECT_SAVE, TABLE_SAVE, TABLE_DELETE));
 
-			$this->sort = array();
-			$this->sort[$this->properties["duedate"]] = TABLE_SORT_DESCEND;
-			
 			$this->start = 0;
 		}
 		/**
@@ -211,5 +211,21 @@
 
 			return $result;
 		}
+
+		/**
+		 * Function will generate property tags based on passed MAPIStore to use
+		 * in module. These properties are regenerated for every request so stores
+		 * residing on different servers will have proper values for property tags.
+		 * @param MAPIStore $store store that should be used to generate property tags.
+		 * @param Binary $entryid entryid of message/folder
+		 * @param Array $action action data sent by client
+		 */
+		function generatePropertyTags($store, $entryid, $action)
+		{
+			$this->properties = $GLOBALS["properties"]->getTaskProperties($store);
+
+			$this->sort = array();
+			$this->sort[$this->properties["duedate"]] = TABLE_SORT_DESCEND;
+		}
 	}
 ?>
\ No newline at end of file
