@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -53,15 +53,18 @@
 	
 	class TodayAppointmentListModule extends ListModule
 	{
+		/**
+		 * @var Array properties of appointment item that will be used to get data
+		 */
+		var $properties = null;
+
 		/**
 		 * Constructor
 		 * @param int $id unique id.
 		 * @param array $data list of all actions.
 		 */
 		function TodayAppointmentListModule($id, $data)
-		{			
-			$this->properties = $GLOBALS["properties"]->getAppointmentProperties();
-			
+		{
 			$this->start = 0;
 			parent::ListModule($id, $data, array(OBJECT_SAVE, TABLE_SAVE, TABLE_DELETE));	
 		}	
@@ -80,6 +83,8 @@
 					$store = $this->getActionStore($action);
 					$parententryid = $this->getActionParentEntryID($action);
 					$entryid = $this->getActionEntryID($action);
+
+					$this->generatePropertyTags($store, $entryid, $action);
 				
 					switch($action["attributes"]["type"])
 					{
@@ -239,5 +244,18 @@
 		   }
 		   return ($start_a < $start_b) ? -1 : 1;
 		}
+
+		/**
+		 * Function will generate property tags based on passed MAPIStore to use
+		 * in module. These properties are regenerated for every request so stores
+		 * residing on different servers will have proper values for property tags.
+		 * @param MAPIStore $store store that should be used to generate property tags.
+		 * @param Binary $entryid entryid of message/folder
+		 * @param Array $action action data sent by client
+		 */
+		function generatePropertyTags($store, $entryid, $action)
+		{
+			$this->properties = $GLOBALS["properties"]->getAppointmentProperties($store);
+		}
 	}
 ?>
