@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -53,6 +53,11 @@
 	
 	class TodayTaskListModule extends ListModule
 	{
+		/**
+		 * @var Array properties of task item that will be used to get data
+		 */
+		var $properties = null;
+
 		/**
 		 * Constructor
 		 * @param int $id unique id.
@@ -60,11 +65,7 @@
 		 */
 		function TodayTaskListModule($id, $data)
 		{
-			$this->properties = $GLOBALS["properties"]->getTaskProperties();
-
 			parent::ListModule($id, $data, array(OBJECT_SAVE, TABLE_SAVE, TABLE_DELETE));
-			$this->sort = array();
-			$this->sort[$this->properties["duedate"]] = TABLE_SORT_DESCEND;
 		}
 
 		/**
@@ -103,8 +104,11 @@
 				$data["sort"]["attributes"]["direction"] = (isset($this->sort[$firstSortColumn]) && $this->sort[$firstSortColumn] == TABLE_SORT_ASCEND) ? "asc" : "desc";
 				$data["sort"]["_content"] = array_search($firstSortColumn, $this->properties);
 
+				if(isset($this->selectedMessageId)) {
+					$this->start = $GLOBALS["operations"]->getStartRow($store, $entryid, $this->selectedMessageId, $this->sort, false, $this->searchRestriction);
+				}
+
 				// Get the table and merge the arrays
-			
 				$data = array_merge($data, $GLOBALS["operations"]->getTable($store, $entryid, $this->properties, $this->sort, $this->start, false, $taskRestriction));
 
 				array_push($this->responseData["action"], $data);
@@ -149,5 +153,21 @@
 
 			return $result;
 		}
+
+		/**
+		 * Function will generate property tags based on passed MAPIStore to use
+		 * in module. These properties are regenerated for every request so stores
+		 * residing on different servers will have proper values for property tags.
+		 * @param MAPIStore $store store that should be used to generate property tags.
+		 * @param Binary $entryid entryid of message/folder
+		 * @param Array $action action data sent by client
+		 */
+		function generatePropertyTags($store, $entryid, $action)
+		{
+			$this->properties = $GLOBALS["properties"]->getTaskProperties($store);
+
+			$this->sort = array();
+			$this->sort[$this->properties["duedate"]] = TABLE_SORT_DESCEND;
+		}
 	}
-?>
\ No newline at end of file
+?>
