@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2009  Zarafa B.V.
+ * Copyright 2005 - 2012  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -201,7 +201,7 @@
 	function inline_attachments($match)
 	{
 		if(array_key_exists("2", $match)) {
-			return "='" . BASE_URL . "index.php?load=download_attachment&store=" . $GLOBALS["preg_replace"]["storeid"] . "&amp;entryid=" . $GLOBALS["preg_replace"]["entryid"] . "&amp;attachNum[]=" . join(",", $GLOBALS["preg_replace"]["attachNum"]) ."&amp;attachCid=" . $match[2] . "&amp;openType=inline'";
+			return "='" . BASE_URL . "index.php?load=download_attachment&store=" . $GLOBALS["preg_replace"]["storeid"] . "&amp;entryid=" . $GLOBALS["preg_replace"]["entryid"] . "&amp;attachNum[]=" . join(",", $GLOBALS["preg_replace"]["attachNum"]) ."&amp;attachCid=" . urlencode($match[2]) . "&amp;openType=inline'";
 		} else {
 			return "=''";
 		}
@@ -226,7 +226,7 @@
 
 			$cid = str_replace("cid:", "", $match[1]);
 
-			return str_replace($match[1], BASE_URL . "index.php?load=download_attachment&store=" . $GLOBALS["preg_replace"]["storeid"] . "&amp;entryid=" . $GLOBALS["preg_replace"]["entryid"] . "&amp;attachNum[]=" . join(",", $GLOBALS["preg_replace"]["attachNum"]) ."&amp;attachCid=" . $cid . "&amp;openType=inline\"", $match[0]);
+			return str_replace($match[1], BASE_URL . "index.php?load=download_attachment&store=" . $GLOBALS["preg_replace"]["storeid"] . "&amp;entryid=" . $GLOBALS["preg_replace"]["entryid"] . "&amp;attachNum[]=" . join(",", $GLOBALS["preg_replace"]["attachNum"]) ."&amp;attachCid=" . urlencode($cid) . "&amp;openType=inline\"", $match[0]);
 		} else {
 			return $match[0];
 		}
@@ -529,7 +529,7 @@
 		if(strpos($_SERVER['HTTP_USER_AGENT'], 'MSIE') === false){
 			return $input;
 		}else{
-			return urlencode($input);
+			return rawurlencode($input);
 		}
 	}
 
